@@ -6,7 +6,6 @@ import warnings
 
 import pytest
 import pyvista
-from pyvista._vtk import VTK9
 
 
 def pytest_addoption(parser):
@@ -36,11 +35,6 @@ def pytest_addoption(parser):
         action="store_true",
         help="Adds images to cache if missing.",
     )
-    group.addoption(
-        "--skip_image_cache_vtk8",
-        action="store_true",
-        help="Skips image cache testing for vtk8.",
-    )
     group.addoption(
         "--image_cache_dir",
         action="store",
@@ -109,7 +103,6 @@ class VerifyImageCache:
     ignore_image_cache = False
     fail_extra_image_cache = False
     add_missing_images = False
-    skip_image_cache_vtk8 = False
 
     def __init__(
         self,
@@ -165,12 +158,6 @@ class VerifyImageCache:
         if self.skip:
             return
 
-        if not VTK9:
-            if self.skip_image_cache_vtk8:
-                return
-            else:
-                raise RuntimeError("Image cache is only valid for VTK9+")
-
         if self.ignore_image_cache:
             return
 
@@ -202,6 +189,8 @@ class VerifyImageCache:
             and self.fail_extra_image_cache
             and not self.reset_image_cache
         ):
+            # Make sure this doesn't get called again if this plotter doesn't close properly
+            plotter._before_close_callback = None
             raise RuntimeError(f"{image_filename} does not exist in image cache")
 
         if (
@@ -219,6 +208,8 @@ class VerifyImageCache:
         error = pyvista.compare_images(image_filename, plotter)
 
         if error > allowed_error:
+            # Make sure this doesn't get called again if this plotter doesn't close properly
+            plotter._before_close_callback = None
             raise RuntimeError(
                 f"{test_name} Exceeded image regression error of "
                 f"{allowed_error} with an image error equal to: {error}"
@@ -242,9 +233,6 @@ def verify_image_cache(request, pytestconfig):
         "fail_extra_image_cache"
     )
     VerifyImageCache.add_missing_images = pytestconfig.getoption("add_missing_images")
-    VerifyImageCache.skip_image_cache_vtk8 = pytestconfig.getoption(
-        "skip_image_cache_vtk8"
-    )
 
     cache_dir = pytestconfig.getoption("image_cache_dir")
     if cache_dir is None:
@@ -257,4 +245,8 @@ def verify_image_cache(request, pytestconfig):
     )
     pyvista.global_theme.before_close_callback = verify_image_cache
 
+    def reset():
+        pyvista.global_theme.before_close_callback = None
+
+    request.addfinalizer(reset)
     return verify_image_cache
